@@ -517,6 +517,7 @@ def add_timezone_on_datetime(dt, default_timezone):
 class DateTimeType(types.TypeDecorator):
 
     impl = types.DateTime(timezone=True)
+    cache_ok = True
 
     def __init__(self, field):
         self.default_timezone = field.default_timezone
@@ -687,6 +688,7 @@ class Interval(Column):
 class StringType(types.TypeDecorator):
 
     impl = types.String
+    cache_ok = True
 
     def process_bind_param(self, value, engine):
         if value is False:
@@ -857,6 +859,7 @@ class Password(Column):
 class TextType(types.TypeDecorator):
 
     impl = types.Text
+    cache_ok = True
 
     def process_bind_param(self, value, engine):
         if value is False:
@@ -933,6 +936,7 @@ class SelectionType(types.TypeDecorator):
     """Generic type for Column Selection """
 
     impl = types.String
+    cache_ok = True
 
     def __init__(self, selections, size, registry=None, namespace=None):
         super(SelectionType, self).__init__(length=size)
@@ -1398,6 +1402,9 @@ class UUID(Column):
         return res
 
 
+URLType.cache_ok = True  # waiting fix from sqlalchemy_utils
+
+
 class URL(Column):
     """URL column
 
@@ -1491,6 +1498,7 @@ class PhoneNumber(Column):
     this method is necessary for encrypt the column
 """
 EmailType.process_result_value = lambda self, value, dialect: value
+EmailType.cache_ok = True  # waiting fix from sqlalchemy_utils
 
 
 class Email(Column):
@@ -1525,6 +1533,7 @@ class CountryType(types.TypeDecorator, ScalarCoercible):
     """Generic type for Column Country """
 
     impl = types.Unicode(3)
+    cache_ok = True
     python_type = python_pycountry_type
 
     def process_bind_param(self, value, dialect):
